# Changelog

## [0.4.0](https://github.com/cademirch/snkmt/compare/v0.3.0...v0.4.0) (2026-03-13)


### Features

* add refresh-interval option and force refresh keybind ([#44](https://github.com/cademirch/snkmt/issues/44)) ([7f8e778](https://github.com/cademirch/snkmt/commit/7f8e7787b14ada9b4b69383e44161d26da89ce38))


### Bug Fixes

* fix issue with workflow details not rendering ([#42](https://github.com/cademirch/snkmt/issues/42)) ([bde2e77](https://github.com/cademirch/snkmt/commit/bde2e77bd8f04705723133b8bf86e71f786597c8))

## [0.3.0](https://github.com/cademirch/snkmt/compare/v0.2.5...v0.3.0) (2026-03-03)


### Features

* delete workflows ([#40](https://github.com/cademirch/snkmt/issues/40)) ([3dcbaac](https://github.com/cademirch/snkmt/commit/3dcbaac3b0394d595b9eca945c11fbd7e40d0a3f))

## [0.2.5](https://github.com/cademirch/snkmt/compare/v0.2.4...v0.2.5) (2026-02-20)


### Bug Fixes

* disable loguru logging by default to prevent debug messages leaking in plugin context ([#36](https://github.com/cademirch/snkmt/issues/36)) ([5dc6122](https://github.com/cademirch/snkmt/commit/5dc6122e2ba6fba9642d0a735466b8025875f779))

## [0.2.4](https://github.com/cademirch/snkmt/compare/v0.2.3...v0.2.4) (2025-12-11)


### Bug Fixes

* properly display pending job count in RuleTable ([#34](https://github.com/cademirch/snkmt/issues/34)) ([8db371a](https://github.com/cademirch/snkmt/commit/8db371a61b9e73ad84adf0cd0d14c238dd4c8234))

## [0.2.3](https://github.com/cademirch/snkmt/compare/v0.2.2...v0.2.3) (2025-10-18)


### Bug Fixes

* make rule table not selectable ([#31](https://github.com/cademirch/snkmt/issues/31)) ([9360502](https://github.com/cademirch/snkmt/commit/9360502b89eb7b3d13237c8e5f9433c69de38bb0))

## [0.2.2](https://github.com/cademirch/snkmt/compare/v0.2.1...v0.2.2) (2025-10-17)


### Bug Fixes

* add version flag, logging cleanup ([#28](https://github.com/cademirch/snkmt/issues/28)) ([778da93](https://github.com/cademirch/snkmt/commit/778da93cbd1098223ea82b3328a13a97fafd4464))
* duplicate workflow id when opening console ([#30](https://github.com/cademirch/snkmt/issues/30)) ([18fc9a2](https://github.com/cademirch/snkmt/commit/18fc9a2e12fb59118a41f38c54744d284d179b76))

## [0.2.1](https://github.com/cademirch/snkmt/compare/v0.2.0...v0.2.1) (2025-09-20)


### Bug Fixes

* use dev branch of logger plugin ([#18](https://github.com/cademirch/snkmt/issues/18)) ([d320f51](https://github.com/cademirch/snkmt/commit/d320f51d514733eb6b1c3b27aea56f7ad663fd6e))

## [0.2.0](https://github.com/cademirch/snkmt/compare/v0.1.2...v0.2.0) (2025-09-20)


### Features

* refactoring; workflow filtering; support multiple databases ([#15](https://github.com/cademirch/snkmt/issues/15)) ([72f3528](https://github.com/cademirch/snkmt/commit/72f35285995cf8ab1c23f59aca8821f7de5e42fe))

## [0.1.2](https://github.com/cademirch/snkmt/compare/v0.1.1...v0.1.2) (2025-08-30)


### Bug Fixes

* remove db logfile ([#8](https://github.com/cademirch/snkmt/issues/8)) ([565fbf7](https://github.com/cademirch/snkmt/commit/565fbf703a7689fd2ebafa597049c6d842a90510))

## [0.1.1](https://github.com/cademirch/snkmt/compare/v0.1.0...v0.1.1) (2025-06-10)


### Bug Fixes

* lower min python version ([3f8c6f8](https://github.com/cademirch/snkmt/commit/3f8c6f826c05bb902ec8eee5a53ee29327b7c650))


### Documentation

* add readme and screenshots ([d45e3fc](https://github.com/cademirch/snkmt/commit/d45e3fc71e4eb727182b8a98ddc881f045650b1a))

## 0.1.0 (2025-06-03)


### Features

* add basic db cli commands ([5dc805b](https://github.com/cademirch/snkmt/commit/5dc805b19b85627aeb52f61fb858332140fa111d))


### Bug Fixes

* dont run migrations if creating new db ([9cd7642](https://github.com/cademirch/snkmt/commit/9cd76423c368c4ad252b45b09b14e98d037a36d0))


### Dependencies

* fix dev dep ([a2ab7a4](https://github.com/cademirch/snkmt/commit/a2ab7a4ef964218261e20471f93b690d36bc868d))
